==> OSCA.workflows_1.12.0.tar.gz: OSCA.workflows/inst/doc/book/index.md <==
--- 
title: "Single-Cell Analysis Workflows with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.19-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: OSCA-source/OSCA.workflows
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Peter Hickey [cre]<br/>
  **Version:** 1.12.0<br/>
  **Modified:** 2024-04-17<br/>
  **Compiled:** 2024-05-03<br/>
  **Environment:** R version 4.4.0 beta (2024-04-15 r86425), Bioconductor 3.19<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2020<br/>
  **Source:** https://github.com/OSCA-source/OSCA.workflows"
url: "https://github.com/OSCA-source/OSCA.workflows"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the workflow chapters of the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.19/OSCA).
This contains worked case studies of analyses of a variety of single-cell datasets, each proceeding from a `SingleCellExperiment` object. Exposition is generally minimal other than for dataset-specific justifications for parameter tweaks;
    refer to the other books in the OCSA collection for a detailed explanation of the theoretical basis of each step. It is intended for readers who already know the background and just want some code to copy and paste into their own analyses.

==> OSCA.workflows_1.13.0.tar.gz: OSCA.workflows/inst/doc/book/index.md <==
--- 
title: "Single-Cell Analysis Workflows with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.20-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: OSCA-source/OSCA.workflows
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Peter Hickey [cre]<br/>
  **Version:** 1.13.0<br/>
  **Modified:** 2024-04-17<br/>
  **Compiled:** 2024-05-01<br/>
  **Environment:** R version 4.4.0 RC (2024-04-16 r86468), Bioconductor 3.19<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2020<br/>
  **Source:** https://github.com/OSCA-source/OSCA.workflows"
url: "https://github.com/OSCA-source/OSCA.workflows"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the workflow chapters of the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.19/OSCA).
This contains worked case studies of analyses of a variety of single-cell datasets, each proceeding from a `SingleCellExperiment` object. Exposition is generally minimal other than for dataset-specific justifications for parameter tweaks;
    refer to the other books in the OCSA collection for a detailed explanation of the theoretical basis of each step. It is intended for readers who already know the background and just want some code to copy and paste into their own analyses.
